@@ -154,7 +154,7 @@ int tpdkg_tp_input_sizes(const TP_DKG_TPState *ctx, size_t *sizes) {
   case 8: { item=tpdkg_msg19_SIZE; break; }
   case 9: { item=tpdkg_msg21_SIZE; break; }
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[!] invalid tp step\n");
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[!] invalid tp step\n");
   }
   }
 
@@ -176,7 +176,7 @@ size_t tpdkg_tp_output_size(const TP_DKG_TPState *ctx) {
   case 7: return 0;
   case 8: return tpdkg_msg20_SIZE;
   case 9: return 0;
-  default: if(log_file!=NULL) fprintf(log_file, "[!] invalid tp step\n");
+  default: if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[!] invalid tp step\n");
   }
   return 0;
 }
@@ -236,13 +236,13 @@ int tpdkg_tp_peer_msg(const TP_DKG_TPState *ctx, const uint8_t *base, const size
     break;
   }
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[!] invalid tp step in tpdkg_tp_peer_msg\n");
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[!] invalid tp step in tpdkg_tp_peer_msg\n");
     return 1;
   }
   }
 
   if(base+base_size < *msg + *len) {
-    if(log_file!=NULL) fprintf(log_file, "buffer overread detected in tpdkg_tp_peer_msg %ld\n", (base+base_size) - (*msg + *len));
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "buffer overread detected in tpdkg_tp_peer_msg %ld\n", (base+base_size) - (*msg + *len));
     return 2;
   }
 
@@ -263,7 +263,7 @@ size_t tpdkg_peer_input_size(const TP_DKG_PeerState *ctx) {
   case 9: return tpdkg_msg20_SIZE;
   case 10: return 0;
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[%d] invalid step\n", ctx->index);
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[%d] invalid step\n", ctx->index);
   }
   }
   return 1;
@@ -291,7 +291,7 @@ size_t tpdkg_peer_output_size(const TP_DKG_PeerState *ctx) {
   case 9: return tpdkg_msg21_SIZE;
   case 10: return 0;
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[%d] invalid step\n", ctx->index);
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[%d] invalid step\n", ctx->index);
   }
   }
   return 1;
@@ -366,7 +366,7 @@ int tpdkg_start_tp(TP_DKG_TPState *ctx, const uint64_t ts_epsilon,
              const uint8_t n, const uint8_t t,
              const char *proto_name, const size_t proto_name_len,
              const size_t msg0_len, DKG_Message *msg0) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 0. start protocol\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 0. start protocol\x1b[0m\n");
   if(2>n || t>=n || n>128) return 1;
   if(proto_name_len<1) return 2;
   if(proto_name_len>1024) return 3;
@@ -412,8 +412,8 @@ int tpdkg_start_tp(TP_DKG_TPState *ctx, const uint64_t ts_epsilon,
   // feed msg0 into transcript
   update_transcript(&ctx->transcript, (uint8_t*) msg0, msg0_len);
 
-  if(log_file!=NULL) {
-    fprintf(log_file,"[!] msgno: %d, from: %d to: 0x%x ", msg0->msgno, msg0->from, msg0->to);
+  if(liboprf_log_file!=NULL) {
+    fprintf(liboprf_log_file,"[!] msgno: %d, from: %d to: 0x%x ", msg0->msgno, msg0->from, msg0->to);
     dump((uint8_t*) msg0, tpdkg_msg0_SIZE, "msg");
   }
 
@@ -423,10 +423,10 @@ int tpdkg_start_tp(TP_DKG_TPState *ctx, const uint64_t ts_epsilon,
 int tpdkg_start_peer(TP_DKG_PeerState *ctx, const uint64_t ts_epsilon,
                const uint8_t peer_lt_sk[crypto_sign_SECRETKEYBYTES],
                const DKG_Message *msg0) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[?] step 0.5 start peer\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[?] step 0.5 start peer\x1b[0m\n");
 
-  if(log_file!=NULL) {
-    fprintf(log_file,"[?] msgno: %d, from: %d to: 0x%x ", msg0->msgno, msg0->from, msg0->to);
+  if(liboprf_log_file!=NULL) {
+    fprintf(liboprf_log_file,"[?] msgno: %d, from: %d to: 0x%x ", msg0->msgno, msg0->from, msg0->to);
     dump((const uint8_t*) msg0, tpdkg_msg0_SIZE, "msg");
   }
 
@@ -465,7 +465,7 @@ int tpdkg_start_peer(TP_DKG_PeerState *ctx, const uint64_t ts_epsilon,
 }
 
 static int tp_step1_handler(const TP_DKG_TPState *ctx, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 1. assign peer indices\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 1. assign peer indices\x1b[0m\n");
   if(output_len!=ctx->n * tpdkg_msg1_SIZE) return 2;
 
   uint8_t* ptr = output;
@@ -478,7 +478,7 @@ static int tp_step1_handler(const TP_DKG_TPState *ctx, uint8_t *output, const si
 }
 
 static int peer_step23_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[?] step 2. receive peers index\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[?] step 2. receive peers index\x1b[0m\n");
   if(input_len != tpdkg_msg1_SIZE) return 1;
   if(output_len != tpdkg_msg2_SIZE+crypto_sign_BYTES) return 2;
 
@@ -489,7 +489,7 @@ static int peer_step23_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
   if(msg1->to > 128 || msg1->to < 1) return 3;
   ctx->index=msg1->to;
 
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 3. send msg2 containing ephemeral pubkey\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 3. send msg2 containing ephemeral pubkey\x1b[0m\n", ctx->index);
 
   crypto_sign_keypair(ctx->sig_pk, ctx->sig_sk);
 
@@ -511,7 +511,7 @@ static int peer_step23_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 }
 
 static int tp_step4_handler(TP_DKG_TPState *ctx, const uint8_t *msg2s, const size_t msg2s_len, uint8_t *msg3_buf, const size_t msg3_buf_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 4. broadcast msg2 containing ephemeral pubkeys of peers\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 4. broadcast msg2 containing ephemeral pubkeys of peers\x1b[0m\n");
   if(((tpdkg_msg2_SIZE + crypto_sign_BYTES) * ctx->n) != msg2s_len) return 1;
   if(msg3_buf_len != (tpdkg_msg2_SIZE * ctx->n) + sizeof(DKG_Message)) return 2;
 
@@ -545,7 +545,7 @@ static int tp_step4_handler(TP_DKG_TPState *ctx, const uint8_t *msg2s, const siz
 }
 
 static int peer_step5_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 5. receive peers ephemeral pubkeys, start noise sessions\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 5. receive peers ephemeral pubkeys, start noise sessions\x1b[0m\n", ctx->index);
   if(input_len != tpdkg_msg2_SIZE * ctx->n + sizeof(DKG_Message)) return 1;
   if(output_len != tpdkg_msg4_SIZE * ctx->n) return 2;
 
@@ -587,7 +587,7 @@ static int peer_step5_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const
 }
 
 static int tp_step68_handler(TP_DKG_TPState *ctx, const uint8_t *msg4s, const size_t msg4s_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step %d. route p2p noise handshakes to peers\x1b[0m\n", 6 + (ctx->step - 1) * 2);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step %d. route p2p noise handshakes to peers\x1b[0m\n", 6 + (ctx->step - 1) * 2);
   if(msg4s_len != tpdkg_msg4_SIZE * ctx->n * ctx->n) return 1;
   if(msg4s_len != output_len) return 2;
 
@@ -596,14 +596,14 @@ static int tp_step68_handler(TP_DKG_TPState *ctx, const uint8_t *msg4s, const si
   for(uint8_t i=0;i<ctx->n;i++) {
     for(uint8_t j=0;j<ctx->n;j++) {
       if(tpdkg_msg4_SIZE != tpdkg_msg5_SIZE) {
-        if(log_file!=NULL) fprintf(log_file, "tpdkg_msg4_SIZE must be equal tpdkg_msg5_SIZE for the check to be correct in tp_step68_handler\n");
+        if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "tpdkg_msg4_SIZE must be equal tpdkg_msg5_SIZE for the check to be correct in tp_step68_handler\n");
         return 3;
       }
       int ret = tp_recv_msg((*inputs)[j][i], tpdkg_msg4_SIZE, (uint8_t) (2+ctx->step), j+1, i+1U, (*ctx->peer_sig_pks)[j], ctx->sessionid, ctx->ts_epsilon, &ctx->last_ts[j]);
       if(0!=ret) {
         if(add_cheater(ctx, 6 + (ctx->step - 1) * 2, 64+ret, j+1U, i+1U) == NULL) return 7;
         const DKG_Message *msg = (const DKG_Message*) (*inputs)[j][i];
-        fprintf(log_file,"[x] msgno: %d, from: %d to: %d ", msg->msgno, msg->from, msg->to);
+        fprintf(liboprf_log_file,"[x] msgno: %d, from: %d to: %d ", msg->msgno, msg->from, msg->to);
         dump((*inputs)[j][i], tpdkg_msg4_SIZE, "msg");
         continue;
       }
@@ -617,7 +617,7 @@ static int tp_step68_handler(TP_DKG_TPState *ctx, const uint8_t *msg4s, const si
 }
 
 static int peer_step7_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 7. receive session requests\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 7. receive session requests\x1b[0m\n", ctx->index);
   if(input_len != tpdkg_msg4_SIZE * ctx->n) return 1;
   if(output_len != tpdkg_msg5_SIZE * ctx->n) return 2;
 
@@ -644,7 +644,7 @@ static int peer_step7_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const
 }
 
 static int peer_step911_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 9-11 finish session handshake, broadcast commitments\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 9-11 finish session handshake, broadcast commitments\x1b[0m\n", ctx->index);
   if(input_len != tpdkg_msg5_SIZE * ctx->n) return 1;
   if(output_len != tpdkg_msg6_SIZE(ctx)) return 2;
 
@@ -663,7 +663,7 @@ static int peer_step911_handler(TP_DKG_PeerState *ctx, const uint8_t *input, con
   if(0!=dkg_start(ctx->n, ctx->t, (uint8_t (*)[32]) msg6->data, *ctx->shares)) return 4;
   if(0!=tp_send_msg(output, tpdkg_msg6_SIZE(ctx), 6, ctx->index, 0xff, ctx->sig_sk, ctx->sessionid)) return 4;
   dkg_dump_msg(output, tpdkg_msg6_SIZE(ctx), ctx->index);
-  if(log_file!=NULL) {
+  if(liboprf_log_file!=NULL) {
     dump(msg6->data, ctx->t*crypto_core_ristretto255_BYTES, "[%d] commitments", ctx->index);
   }
 
@@ -671,7 +671,7 @@ static int peer_step911_handler(TP_DKG_PeerState *ctx, const uint8_t *input, con
 }
 
 static int tp_step12_handler(TP_DKG_TPState *ctx, const uint8_t *msg6s, const size_t msg6s_len, uint8_t *msg7_buf, const size_t msg7_buf_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 12. broadcast commitments of peers\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 12. broadcast commitments of peers\x1b[0m\n");
 
   if((tpdkg_msg6_SIZE(ctx) * ctx->n) != msg6s_len) return 1;
   if(msg7_buf_len != sizeof(DKG_Message) + msg6s_len) return 2;
@@ -687,7 +687,7 @@ static int tp_step12_handler(TP_DKG_TPState *ctx, const uint8_t *msg6s, const si
     }
 
     memcpy((*ctx->commitments)[i*ctx->t], msg->data, crypto_core_ristretto255_BYTES * ctx->t);
-    if(log_file!=NULL) {
+    if(liboprf_log_file!=NULL) {
       dump((*ctx->commitments)[i*ctx->t], crypto_core_ristretto255_BYTES * ctx->t, "[!] commitments[%d]", i+1U);
     }
 
@@ -706,7 +706,7 @@ static int tp_step12_handler(TP_DKG_TPState *ctx, const uint8_t *msg6s, const si
 }
 
 static int peer_step13_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 13. receive commitments, distribute shares via noise chans\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 13. receive commitments, distribute shares via noise chans\x1b[0m\n", ctx->index);
   if(input_len != sizeof(DKG_Message) + (tpdkg_msg6_SIZE(ctx) * ctx->n)) return 1;
   if(output_len != ctx->n * tpdkg_msg8_SIZE) return 2;
 
@@ -768,7 +768,7 @@ static int peer_step13_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 }
 
 static int tp_step14_handler(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 14. route shares from all peers to all peers\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 14. route shares from all peers to all peers\x1b[0m\n");
   if(input_len != tpdkg_msg8_SIZE * ctx->n * ctx->n) return 1;
   if(input_len != output_len) return 2;
 
@@ -796,7 +796,7 @@ static int tp_step14_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
 }
 
 static int peer_step15_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 15. DKG step 2 - receive shares, verify commitments\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 15. DKG step 2 - receive shares, verify commitments\x1b[0m\n", ctx->index);
   if(input_len != ctx->n * tpdkg_msg8_SIZE) return 1;
   if(output_len != tpdkg_msg9_SIZE(ctx)) return 2;
 
@@ -845,9 +845,9 @@ static int peer_step15_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
   }
 #endif //UNITTEST_CORRUPT
 
-  if(log_file!=NULL) {
+  if(liboprf_log_file!=NULL) {
     for(int j=0;j<*fails_len;j++) {
-      fprintf(log_file,"\x1b[0;31m[%d] failed to verify commitments from %d!\x1b[0m\n", ctx->index, fails[j]);
+      fprintf(liboprf_log_file,"\x1b[0;31m[%d] failed to verify commitments from %d!\x1b[0m\n", ctx->index, fails[j]);
     }
   }
 
@@ -858,7 +858,7 @@ static int peer_step15_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 }
 
 static int tp_step16_handler(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 16. broadcast complaints of peers\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 16. broadcast complaints of peers\x1b[0m\n");
 
   if((tpdkg_msg9_SIZE(ctx) * ctx->n) != input_len) return 1;
   if(output_len != tpdkg_msg10_SIZE(ctx)) return 2;
@@ -891,8 +891,8 @@ static int tp_step16_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
         continue;
       }
       (*ctx->complaints)[ctx->complaints_len++] = pair;
-      if(log_file!=NULL) {
-        fprintf(log_file,"\x1b[0;31m[!] peer %d failed to verify commitments from peer %d!\x1b[0m\n", i+1U, msg->data[1+k]);
+      if(liboprf_log_file!=NULL) {
+        fprintf(liboprf_log_file,"\x1b[0;31m[!] peer %d failed to verify commitments from peer %d!\x1b[0m\n", i+1U, msg->data[1+k]);
       }
     }
 
@@ -919,7 +919,7 @@ static int tp_step16_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
 }
 
 static int peer_step17_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 17. receive complaints broadcast\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 17. receive complaints broadcast\x1b[0m\n", ctx->index);
   if(input_len != tpdkg_msg10_SIZE(ctx)) return 1;
 
   // verify TP message envelope
@@ -950,7 +950,7 @@ static int peer_step17_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 
       if(msg9->data[k+1] == ctx->index) {
         ctx->my_complaints[ctx->my_complaints_len++] = i+1U;
-        if(log_file!=NULL) fprintf(log_file,"\x1b[0;31m[%d] peer %d failed to verify commitments from peer %d!\x1b[0m\n", ctx->index, i+1U, msg9->data[1+k]);
+        if(liboprf_log_file!=NULL) fprintf(liboprf_log_file,"\x1b[0;31m[%d] peer %d failed to verify commitments from peer %d!\x1b[0m\n", ctx->index, i+1U, msg9->data[1+k]);
       }
     }
 
@@ -966,11 +966,11 @@ static int peer_step17_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 }
 
 static int peer_step17a_handler(TP_DKG_PeerState *ctx, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 17a. potentially broadcast contested shares\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 17a. potentially broadcast contested shares\x1b[0m\n", ctx->index);
   if(output_len != tpdkg_peer_output_size(ctx)) return 2;
   if(output_len == 0) {
-    if(log_file!=NULL) {
-      fprintf(log_file,"[%d] nothing to defend against, no message to send\n", ctx->index);
+    if(liboprf_log_file!=NULL) {
+      fprintf(liboprf_log_file,"[%d] nothing to defend against, no message to send\n", ctx->index);
     }
     return 0;
   }
@@ -979,7 +979,7 @@ static int peer_step17a_handler(TP_DKG_PeerState *ctx, uint8_t *output, const si
   DKG_Message* msg11 = (DKG_Message*) output;
   uint8_t *wptr = msg11->data;
   for(int i=0;i<ctx->my_complaints_len;i++) {
-    if(log_file!=NULL) fprintf(log_file, "\x1b[0;36m[%d] defending against complaint from %d\x1b[0m\n", ctx->index, ctx->my_complaints[i]);
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;36m[%d] defending against complaint from %d\x1b[0m\n", ctx->index, ctx->my_complaints[i]);
 
     *wptr++ = ctx->my_complaints[i];
     // reveal key for noise wrapped share sent previously
@@ -997,7 +997,7 @@ static int peer_step17a_handler(TP_DKG_PeerState *ctx, uint8_t *output, const si
 }
 
 static int tp_step18_handler(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 18. collect keys of contested shares and verify the commitments\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 18. collect keys of contested shares and verify the commitments\x1b[0m\n");
   if(input_len != tpdkg_tp_input_size(ctx)) return 1;
 
   unsigned int ctr[ctx->n];
@@ -1093,8 +1093,8 @@ static int tp_step18_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
         continue;
       }
 
-      if(log_file!=NULL) {
-        fprintf(log_file, "[!] checking proof of peer %d for complaint by peer %d\n", msg->from, share.index);
+      if(liboprf_log_file!=NULL) {
+        fprintf(liboprf_log_file, "[!] checking proof of peer %d for complaint by peer %d\n", msg->from, share.index);
         dump((void*) &share, sizeof(TOPRF_Share), "[!] share_%d,%d", msg->from, share.index);
         dump((*ctx->commitments)[(msg->from-1) * ctx->t], ctx->t * crypto_core_ristretto255_BYTES, "[!] commitments_%d", msg->from);
       }
@@ -1106,20 +1106,20 @@ static int tp_step18_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
       switch(ret) {
       case 0: {
         // verified correctly
-        if(log_file!=NULL) fprintf(log_file, "\x1b[0;32m[!] complaint against %d by %d invalid, proof correct\x1b[0m\n", msg->from, share.index);
+        if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;32m[!] complaint against %d by %d invalid, proof correct\x1b[0m\n", msg->from, share.index);
 
         if(add_cheater(ctx, 18, 128+ret, accused, complainer) == NULL) return 4;
         break;
       }
       case 1: {
         // confirmed corrupt
-        if(log_file!=NULL) fprintf(log_file, "\x1b[0;31m[!] complaint against %d by %d valid, proof incorrect\x1b[0m\n", msg->from, share.index);
+        if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;31m[!] complaint against %d by %d valid, proof incorrect\x1b[0m\n", msg->from, share.index);
         if(add_cheater(ctx, 18, 128+ret, accused, complainer) == NULL) return 4;
         break;
       }
       case -1: {
         // invalid input
-        if(log_file!=NULL) fprintf(log_file, "\x1b[0;31m[!] complaint against %d by %d, cannot be verified, invalid input\x1b[0m\n", msg->from, share.index);
+        if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;31m[!] complaint against %d by %d, cannot be verified, invalid input\x1b[0m\n", msg->from, share.index);
 
         if(add_cheater(ctx, 18, 128+ret, accused, complainer) == NULL) return 4;
         break;
@@ -1140,7 +1140,7 @@ static int tp_step18_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
 }
 
  static int peer_step19_handler(TP_DKG_PeerState *ctx, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 19. send final transcript\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 19. send final transcript\x1b[0m\n", ctx->index);
   if(output_len != tpdkg_msg19_SIZE) return 2;
 
   DKG_Message* msg20 = (DKG_Message*) output;
@@ -1152,7 +1152,7 @@ static int tp_step18_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
 }
 
 static int tp_step20_handler(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 20. collect and verify transcripts\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 20. collect and verify transcripts\x1b[0m\n");
 
   if((tpdkg_msg19_SIZE * ctx->n) != input_len) return 1;
   if(output_len != tpdkg_msg20_SIZE) return 2;
@@ -1175,8 +1175,8 @@ static int tp_step20_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
     }
 
     if(sodium_memcmp(transcript_hash, msg->data, sizeof(transcript_hash))!=0) {
-      if(log_file!=NULL) {
-        fprintf(log_file,"\x1b[0;31m[!] failed to verify transcript from %d!\x1b[0m\n", i);
+      if(liboprf_log_file!=NULL) {
+        fprintf(liboprf_log_file,"\x1b[0;31m[!] failed to verify transcript from %d!\x1b[0m\n", i);
       }
       if(add_cheater(ctx, 20, 1, i+1U, 0) == NULL) return 4;
       memcpy(wptr,"NO",2);
@@ -1192,7 +1192,7 @@ static int tp_step20_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
 }
 
 static int peer_step21_handler(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t input_len, uint8_t *output, const size_t output_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[%d] step 21. get final approval\x1b[0m\n", ctx->index);
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[%d] step 21. get final approval\x1b[0m\n", ctx->index);
   if(input_len != tpdkg_msg20_SIZE) return 1;
   if(output_len != tpdkg_msg21_SIZE) return 2;
 
@@ -1217,7 +1217,7 @@ static int peer_step21_handler(TP_DKG_PeerState *ctx, const uint8_t *input, cons
 }
 
 static int tp_step22_handler(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_len) {
-  if(log_file!=NULL) fprintf(log_file, "\x1b[0;33m[!] step 22. collect acks from peers\x1b[0m\n");
+  if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "\x1b[0;33m[!] step 22. collect acks from peers\x1b[0m\n");
 
   if((tpdkg_msg21_SIZE * ctx->n) != input_len) return 1;
 
@@ -1232,8 +1232,8 @@ static int tp_step22_handler(TP_DKG_TPState *ctx, const uint8_t *input, const si
     }
 
     if(memcmp("OK", msg->data, 2)!=0) {
-      if(log_file!=NULL) {
-        fprintf(log_file,"\x1b[0;31m[!] failed to get ack from %d!\x1b[0m\n", i);
+      if(liboprf_log_file!=NULL) {
+        fprintf(liboprf_log_file,"\x1b[0;31m[!] failed to get ack from %d!\x1b[0m\n", i);
       }
     }
   }
@@ -1265,7 +1265,7 @@ int tpdkg_tp_next(TP_DKG_TPState *ctx, const uint8_t *input, const size_t input_
   case 8: {ret = tp_step20_handler(ctx, input, input_len, output, output_len); break;}
   case 9: {ret = tp_step22_handler(ctx, input, input_len); break;}
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[!] invalid step\n");
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[!] invalid step\n");
     return 99;
   }
   }
@@ -1293,7 +1293,7 @@ int tpdkg_peer_next(TP_DKG_PeerState *ctx, const uint8_t *input, const size_t in
     break;
   }
   default: {
-    if(log_file!=NULL) fprintf(log_file, "[%d] invalid step\n", ctx->index);
+    if(liboprf_log_file!=NULL) fprintf(liboprf_log_file, "[%d] invalid step\n", ctx->index);
     ret = 99;
   }
   }
